[chirp_devel] [PATCH][ft2900] fix lockup issue (#2505)
Richard Cochran
Mon Apr 6 22:08:53 PDT 2015
# HG changeset patch
# User Richard Cochran <ag6qr at sonic.net>
# Date 1428383013 25200
# Mon Apr 06 22:03:33 2015 -0700
# Node ID 135494ac7732f1de094fea16268a7bd72d824253
# Parent e8bd104b88b3fa593931d55957c7acef58d9fe89
[ft2900] fix lockup issue (#2505)
This fixes an issue where memories entered via the Chirp UI and uploaded
to the radio could sometimes cause lockups if the memory was later edited
in the radio to change its SQLTYPE. The cause was uninitized flags
that could erroneously flag a tone or DCS code as being part of a split
tone. Fix is to initialize the flags to zero -- there was already code
to set them to 1 when needed.
diff -r e8bd104b88b3 -r 135494ac7732 chirp/drivers/ft2900.py
--- a/chirp/drivers/ft2900.py Sat Apr 04 09:20:40 2015 -0700
+++ b/chirp/drivers/ft2900.py Mon Apr 06 22:03:33 2015 -0700
@@ -548,6 +548,13 @@
_mem.freq = mem.freq / 1000
_mem.offset = mem.offset / 1000
_mem.duplex = DUPLEX.index(mem.duplex)
+
+ # clear all the split tone flags -- we'll set them as needed below
+ _mem.ctonesplitflag = 0
+ _mem.rx_dtcssplitflag = 0
+ _mem.rtonesplitflag = 0
+ _mem.dtcssplitflag = 0
+
if mem.tmode != "Cross":
_mem.tmode = TMODES.index(mem.tmode)
# for the non-cross modes, use ONE tone for both send
@@ -570,9 +577,9 @@
_mem.rx_dtcs = chirp_common.DTCS_CODES.index(mem.rx_dtcs)
if mem.cross_mode == "Tone->Tone":
# tone->tone cross mode is treated as
# Tone, but with separate tones for
# send and receive
- _mem.tmode = TMODES.index("Tone")
+ _mem.tmode = TMODES.index("TSQL")
_mem.rtonesplitflag = 1
elif mem.cross_mode == "DTCS->DTCS":
# DTCS->DTCS cross mode is treated as
@@ -570,9 +577,9 @@
if mem.cross_mode == "Tone->Tone":
# tone->tone cross mode is treated as
- # Tone, but with separate tones for
+ # TSQL, but with separate tones for
# send and receive
More information about the chirp_devel
mailing list